==> kube-integration-1.23.8.tgz: package/config/index.js <==
'use strict';

const _    = require('lodash');
const path = require('path');
const os   = require('os');
const { getRequestId, getAuthenticatedEntity } = require('@codefresh-io/http-infra');

const name = 'kube-integration';

const base = {};

base.env  = process.env.NODE_ENV || 'kubernetes';
base.port = process.env.PORT || 9003;
base.name = name;

base.logger = {
    filePath: process.env.LOGS_PATH || path.join(__dirname, '../../logs', 'kubernetes-logs.log'),
    console: true,
    handleExceptions: false,
    showNamespace: true,
    env_module: `${name}_${os.hostname()}`,
    showRequestId: true,
    level: "debug",
    consoleOptions: {
        timestamp: function () {
            return new Date().toISOString();
        },
        formatter: function (options) {
            // Return string will be passed to logger.
            const shouldFormatOutput = !!process.env['FORMAT_LOGS_TO_ELK'];
            if (shouldFormatOutput) {
                return JSON.stringify({
                    metadata: options.meta || {},
                    data: Object.assign(options.data || {}, { message: options.message }),
                });
            }
            // human readable format
            return `${options.timestamp()} ${options.level.toUpperCase()} >> ` +
            `${options.message || ''}` +
            `${options.meta && Object.keys(options.meta).length ? ` << ${JSON.stringify(options.meta)}` : ''}`;
        }
    },
    basePath: null,
    baseNamespace: "codefresh",
    fields: {
        service: process.env['SERVICE_NAME'] || 'service-base',
        time: () => { return new Date().toISOString(); },
        correlationId: () => {
            try {
                return getRequestId();
            } catch (err) {
                return {};
            }
        },
        user: () => {
            try {
                const { _user: { name, _id } } = getAuthenticatedEntity();
                return { name, _id };
            } catch (err) {
                return {};
            }
        }
    }
};

base.httpLogger = {
    level: process.env.HTTP_LOGGER_LEVEL || 'debug',
    format: 'dev'
};

base.newrelic = {
    license_key: process.env.NEWRELIC_LICENSE_KEY
};

base.mongo = {
    uri: process.env.MONGO_URI || 'mongodb://codefresh.dev:27017/kube',
    reconnectTries: process.env.MONGO_RECONNECT_TRIES || Number.MAX_VALUE,
    reconnectInterval: process.env.MONGO_RECONNECT_INTERVAL || 30 * 1000
};

base.eventbus = {
    uri: process.env.EVENTBUS_URI || 'amqp://codefresh.dev',
    reconnectInterval: process.env.EVENTBUS_INTERVAL || 5,
    serviceName: name
};

base.postgres = {
    host: process.env.POSTGRES_HOST || 'codefresh.dev',
    database: process.env.POSTGRES_DATABASE || 'postgres',
    user: process.env.POSTGRES_USER || 'postgres',
    password: process.env.POSTGRES_PASSWORD || 'postgres'
};

base.helm = {
    maxHelmHistorySize: process.env.MAX_HELM_HISTORY_SIZE, // If set, limits history in release
};

require(`./environment/kubernetes`)(base);


module.exports = base;

==> kube-integration-1.24.0.tgz: package/config/index.js <==
'use strict';

const path = require('path');
const os = require('os');
const fs = require('fs');
const { getRequestId, getAuthenticatedEntity } = require('@codefresh-io/http-infra');

const name = 'kube-integration';

const base = {};

base.env = process.env.NODE_ENV || 'kubernetes';
base.port = process.env.PORT || 9003;
base.name = name;

base.logger = {
    filePath: process.env.LOGS_PATH || path.join(__dirname, '../../logs', 'kubernetes-logs.log'),
    console: true,
    handleExceptions: false,
    showNamespace: true,
    env_module: `${name}_${os.hostname()}`,
    showRequestId: true,
    level: "debug",
    consoleOptions: {
        timestamp: function () {
            return new Date().toISOString();
        },
        formatter: function (options) {
            // Return string will be passed to logger.
            const shouldFormatOutput = !!process.env['FORMAT_LOGS_TO_ELK'];
            if (shouldFormatOutput) {
                return JSON.stringify({
                    metadata: options.meta || {},
                    data: Object.assign(options.data || {}, { message: options.message }),
                });
            }
            // human readable format
            return `${options.timestamp()} ${options.level.toUpperCase()} >> ` +
                `${options.message || ''}` +
                `${options.meta && Object.keys(options.meta).length ? ` << ${JSON.stringify(options.meta)}` : ''}`;
        }
    },
    basePath: null,
    baseNamespace: "codefresh",
    fields: {
        service: process.env['SERVICE_NAME'] || 'service-base',
        time: () => { return new Date().toISOString(); },
        correlationId: () => {
            try {
                return getRequestId();
            } catch (err) {
                return {};
            }
        },
        user: () => {
            try {
                const { _user: { name, _id } } = getAuthenticatedEntity();
                return { name, _id };
            } catch (err) {
                return {};
            }
        }
    }
};

base.httpLogger = {
    level: process.env.HTTP_LOGGER_LEVEL || 'debug',
    format: 'dev'
};

base.newrelic = {
    license_key: process.env.NEWRELIC_LICENSE_KEY
};

base.mongo = {
    uri: process.env.MONGO_URI || 'mongodb://codefresh.dev:27017/kube',
    options: {
        reconnectTries: process.env.MONGO_RECONNECT_TRIES || Number.MAX_VALUE,
        reconnectInterval: process.env.MONGO_RECONNECT_INTERVAL || 30 * 1000
    }
};

base.eventbus = {
    uri: process.env.EVENTBUS_URI || 'amqp://codefresh.dev',
    reconnectInterval: process.env.EVENTBUS_INTERVAL || 5,
    serviceName: name
};

base.postgres = {
    host: process.env.POSTGRES_HOST || 'codefresh.dev',
    database: process.env.POSTGRES_DATABASE || 'postgres',
    user: process.env.POSTGRES_USER || 'postgres',
    password: process.env.POSTGRES_PASSWORD || 'postgres',
    port: process.env.POSTGRES_PORT || 5432
};

base.helm = {
    maxHelmHistorySize: process.env.MAX_HELM_HISTORY_SIZE, // If set, limits history in release
};

if (process.env.MTLS_CERT_PATH) {
    const credentials = fs.readFileSync(process.env.MTLS_CERT_PATH);
    base.mongo.options.sslKey = credentials;
    base.mongo.options.sslCert = credentials;
}

require(`./environment/kubernetes`)(base);

module.exports = base;
